#
# spec file for package anjuta
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           anjuta
Version:        3.34.0
Release:        5.11
Summary:        Versatile Integrated Development Environment for GNOME
License:        GPL-2.0-or-later
Group:          Development/Tools/IDE
URL:            https://wiki.gnome.org/Apps/Anjuta
Source0:        https://download.gnome.org/sources/anjuta/3.34/%{name}-%{version}.tar.xz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM libgda-6.patch gmbr3@opensuse.org -- Require and support GDA 6
Patch0:         libgda-6.patch
BuildRequires:  autogen
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libapr-util1-devel
BuildRequires:  libapr1-devel
BuildRequires:  libvala-devel
BuildRequires:  libxslt-devel
BuildRequires:  perl-gettext
BuildRequires:  pkgconfig
BuildRequires:  sqlite3-devel
BuildRequires:  subversion-devel
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.0.0
BuildRequires:  pkgconfig(gdl-3.0) >= 3.5.5
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.12.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.34.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.6.0
BuildRequires:  pkgconfig(gtksourceview-3.0) >= 3.0.0
#BuildRequires:  pkgconfig(libdevhelp-3.0) >= 3.7.5
BuildRequires:  pkgconfig(libgda-6.0) >= 6.0.0
BuildRequires:  pkgconfig(libgvc)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.23
BuildRequires:  pkgconfig(serf-1)
BuildRequires:  pkgconfig(vte-2.91)
# Directly required by anjuta:
Requires:       autoconf
Requires:       autogen
Requires:       automake
Requires:       gettext
# libgda-sqlite is needed by the symbol-db plugin. See bnc#624924.
Requires:       libgda-sqlite >= 6.0.0
Requires:       libtool
%ifnarch ia64 s390 s390x aarch64 ppc64le
BuildRequires:  valgrind-devel
%endif

%description
Anjuta is a versatile Integrated Development Environment (IDE) for the
GNOME desktop. It features a number of advanced programming facilities
includes project management, application wizards, an interactive
debugger, an integrated Glade UI designer, integrated Devhelp API help,
an integrated Valgrind memory profiler, an integrated gprof performance
profiler, a class generator, a powerful source editor, source browsing,
and more.

%package -n libanjuta-3-0
Summary:        Library for developing Anjuta plugins
Group:          System/Libraries

%description -n libanjuta-3-0
Anjuta is a versatile Integrated Development Environment (IDE) for the
GNOME desktop.

%package -n typelib-1_0-Anjuta-3_0
Summary:        Introspection bindings for the Anjuta plugin library
Group:          System/Libraries

%description -n typelib-1_0-Anjuta-3_0
Anjuta is a versatile Integrated Development Environment (IDE) for the
GNOME desktop.

This package provides the GObject Introspection bindings for the Anjuta
library to develop plugins.

%package -n glade-catalog-anjuta
Summary:        Glade catalog for Anjuta
Group:          Development/Tools/GUI Builders
Requires:       %{name} = %{version}
Requires:       glade
Supplements:    packageand(glade:%{name}-devel)

%description -n glade-catalog-anjuta
Anjuta is a versatile Integrated Development Environment (IDE) for the
GNOME desktop.

This package provides a catalog for Glade, to allow the use the Anjuta
widgets in Glade.

%package devel
Summary:        Development files for Anjuta plugins
Group:          Development/Libraries/C and C++
Requires:       libanjuta-3-0 = %{version}
Requires:       typelib-1_0-Anjuta-3_0 = %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
Anjuta is a versatile Integrated Development Environment (IDE) for the
GNOME desktop.

%lang_package

%prep
%autosetup -p1

%build
export AUTOPOINT='intltoolize --automake --copy'
autoreconf -fiv
%configure\
        --disable-static \
        --enable-glade-catalog \
        --disable-plugin-devhelp \
        %{nil}
%make_build

%install
%make_install
# These should go to defaultdocdir.
rm -r %{buildroot}%{_datadir}/doc
%find_lang anjuta %{?no_lang_C}
%find_lang anjuta-faqs %{no_lang_C} %{name}.lang
# There's no translation for those yet. If build fails because of non-packaged
# translations, uncomment those lines.
%find_lang anjuta-build-tutorial %{?no_lang_C} anjuta.lang
#%%find_lang anjuta-faqs %{?no_lang_C} anjuta.lang
%find_lang anjuta-manual %{?no_lang_C} anjuta.lang
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}/%{_prefix}

%post -n libanjuta-3-0 -p /sbin/ldconfig
%postun -n libanjuta-3-0 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS README doc/ScintillaDoc.html
%doc %{_datadir}/help/C/anjuta-build-tutorial/
%doc %{_datadir}/help/C/anjuta-faqs/
%doc %{_datadir}/help/C/anjuta-manual/
%{_bindir}/anjuta
%{_bindir}/anjuta-launcher
%{_bindir}/anjuta-tags
%{_libdir}/anjuta/
%{_datadir}/anjuta/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/anjuta.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/*.xml
%{_datadir}/pixmaps/anjuta/
%{_datadir}/glib-2.0/schemas/*.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/mimetypes/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/icons/hicolor/scalable/mimetypes/*.svg
%{_datadir}/icons/hicolor/symbolic/apps/anjuta-symbolic.svg
%{_mandir}/man?/*%{ext_man}

%files -n libanjuta-3-0
%{_libdir}/libanjuta-3.so.*

%files -n typelib-1_0-Anjuta-3_0
%{_libdir}/girepository-1.0/Anjuta-3.0.typelib
%{_libdir}/girepository-1.0/IAnjuta-3.0.typelib

%files -n glade-catalog-anjuta
%{_libdir}/glade/modules/libgladeanjuta.so
%{_datadir}/glade/catalogs/anjuta-glade.xml

%files devel
%doc ChangeLog FUTURE TODO
# Own these directories to avoid requirement on gtk-doc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/libanjuta/
%{_includedir}/libanjuta-3.0/
%{_libdir}/libanjuta-3.so
%{_libdir}/pkgconfig/libanjuta-3.0.pc
%{_datadir}/gir-1.0/*.gir

%files lang -f %{name}.lang

%changelog
* Tue Aug 30 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Disable devhelp plugin, we can no longer support this due to
  changes in devhelp building against to new webkitgtk. Disable
  pkgconfig(libdevhelp-3.0) BuildRequires and pass
  disable-plugin-devhelp to configure.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Feb 14 2021 Callum Farmer <gmbr3@opensuse.org>
- Add libgda-6.patch: support GDA 6
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Replace Bugzilla by Gitlab URL in DOAP file.
  + Add new vala version.
  + anjuta-tags: fix tag for vala language.
  + Convert README to markdown.
  + Add build rule so that README is not flagged as missing.
  + build: Allow building with vala 0.44.
  + Fix error in distcheck.
  + build: Don't require exact match in the bison check.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Thu Mar 15 2018 dimstar@opensuse.org
- Replace pkgconfig(libvala-0.38) BuildRequires with libvala-devel.
* Sun Mar 11 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + help: Fix build-tutorial.
  + Fix a random crash when vim modelines are used.
  + Updated translations.
- Drop:
  - update-desktop-files BuildRequires and its macro: they are no
    longer required anymore.
  - shared-mime-info BuildRequires, and glib2_gsettings_schema_*,
    desktop_database_*, icon_theme_cache_* and mime_database_*
    post/postun scriptlets and glib2_gsettings_schema_requires
    macro: their functionality has been moved to RPM file triggers
    (RPM 4.13, suse_vesion 1330).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Sep 10 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Remove some untracked files from git status (bgo#787473).
  + Language-support-vala fails to build with vala 0.38
    (bgo#786973).
  + Updated translations.
- Stop passing --disable-vala to configure, bug fixed upstream.
* Fri Sep  8 2017 jengelh@inai.de
- Trim descriptions in secondary packages, and update summaries.
  Do not run fdupes across hardlink boundaries.
* Wed Aug 30 2017 dimstar@opensuse.org
- Pass --disable-vala to configure until bgo#786973 is resolved.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + bgo#782633: Scintilla editor occupies 100%% of a core after
    switching tabs.
  + bgo#782452: Using #!/usr/bin/perl in scripts is not portable.
  + Avoid errors with recent version of gcc.
  + gdb: bgo#783380: Unable to debug executable compiled with -pie
    option.
  + bgo#770822: "Search for example code" points to discontinued
    webpage
  + bgo#763115: Anjuta builds are not reproducible.
  + Fix some compiler warnings.
  + Fix warning misleading-indentation.
  + Remove obsolete CSS properties.
  + Remove deprecated flags.
  + Fix some run time critical warnings.
  + Avoid an endless loop when updating a project.
  + Fix another crash when updating project files.
  + bgo#786309: segfault when shm support is missing.
  + gtksourceview: Ignore changes that happen during a save.
  + symbol-db: add support for libgda-6.0.
  + Support reproducible builds.
  + manuals: Remove extra - symbols before =.
  + Allow building with vala 0.36 and 0.38.
  + bgo#771625: needs support for vala 0.34.
  + Fix callback generation when user_data is set on glade.
  + Fix translator comments.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Drop anjuta-vala-0.34.patch and anjuta-fix-gcc7-build.patch:
  Fixed upstream, following this, drop gnome-common BuildRequires:
  and autogen.sh call, no longer needed.
* Thu Jul 20 2017 zaitor@opensuse.org
- Build with vala 0.38:
  + Replace pkgconfig(libvala-0.36) BuildRequires with
    pkgconfig(libvala-0.38).
  + Extend anjuta-vala-0.34.patch: add support for vala 0.38.
* Sat Jun  3 2017 zaitor@opensuse.org
- Add anjuta-fix-gcc7-build.patch: Fix build with gcc7.
* Fri Nov 25 2016 dimstar@opensuse.org
- Build with vala 0.36:
  + Replace pkgconfig(libvala-0.34) BuildRequires with
    pkgconfig(libvala-0.36).
  + Extend anjuta-vala-0.34.patch: add support for vala 0.36.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Improve vala current context location.
  + Updated translations.
* Thu Sep 15 2016 dimstar@opensuse.org
- Build with vala 0.34:
  + Replace pkgconfig(libvala-0.32) BuildRequires with
    pkgconfig(libvala-0.34).
  + Add anjuta-vala-0.34.patch: add support for vala 0.34.
  + Add gnome-common BuildRequires and call to autogen.sh: above
    patch touches the build system.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + build: add support for Vala 0.32.
  + sourceview: Anjuta show "The file ... has been deleted on the
    disk" everytime I save file (bgo#756426).
  + Check for yelp-tools to avoid an error later.
  + Update the AppData file to version 0.7+.
  + Updated translations.
- Remove out sed hack to support newer vala version.
* Fri Feb 12 2016 zaitor@opensuse.org
- Use sed to support vala-0.32, and due to this change replace
  pkgconfig(libvala-0.30) for pkgconfig(libvala-0.32).
* Sat Nov  7 2015 badshah400@gmail.com
- Update to version 3.18.2:
  + bgo#756426: Anjuta shows "The file ... has been deleted on the
    disk" everytime upon file save.
  + Updated translations.
- Drop anjuta-file-deleted-upon-save.patch: incorporated upstream.
* Sat Nov  7 2015 badshah400@gmail.com
- Add anjuta-file-deleted-upon-save.patch to prevent showing
  "The file ... has been deleted on the disk" everytime upon file
  save (bgo#756426); patch taken from upstream master.
* Sun Sep 20 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Provide a symbolic variant of the app icon.
  + Fix build error on Mac OS X.
  + bgo#753255: Typos in translatable strings.
  + Fix typos in manuals.
  + Fix typos.
  + Updated translations.
- Update Url to new home.
* Thu May 28 2015 zaitor@opensuse.org
- Use sed to support vala-0.30, and due to this change replace
  pkgconfig(libvala-0.28) for pkgconfig(libvala-0.30).
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
- Drop 0001-build-detect-vala-0.28-branch.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to autogen.sh, as we no
  longer carry any patches.
* Thu Feb  5 2015 dimstar@opensuse.org
- Add 0001-build-detect-vala-0.28-branch.patch: Add support for
  Vala 0.28 branch.
- Add gnome-common BuildRequires and call to autogen.sh, as above
  patch touches the build system.
- Replace pkgconfig(libvala-0.26) BuildRequires with
  pkgconfig(libvala-0.28).
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + symbol-db:
  - anjuta-tags: build breakage with recent glib (bgo#733600).
  - Provide better error message if one GDA backend is missing.
* Sun Jan 25 2015 zaitor@opensuse.org
- Update to version 3.14.1:
  + Many debugging commands are broken (bgo#743270).
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Sun Sep 14 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Support webkit2gtk-4.0.
  + Removed useless mark for translation.
  + Updated translations.
- Drop anjuta-devhelp-webkit2.patch: fixed upstream
- Drop gnome-common BuildRequires and call to autogen.sh: no longer
  needed, as no patch touches the build system.
* Sun Aug 24 2014 dimstar@opensuse.org
- Add anjuta-devhelp-webkit2.patch: Detect if devhelp was built
  against webkit2gtk-4.0.
- Add gnome-common BuildRequires and call to autogen.sh, as above
  patch touches the build system.
* Sat Aug 23 2014 dimstar@opensuse.org
- Replace pkgconfig(libvala-0.24) BuildRequires with
  pkgconfig(libvala-0.26): GNOME 3.14 uses Vala 0.26 as default.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + terminal:
  - Support vte-2.90 or vte-2.91.
  - Crash if gnome-terminal is not installed (bgo#728295).
  + project-wizard:
  - Suggestion to use a Glade prompted handler name rather than
    "destroy" (bgo#732672).
  - parameters reversed in template main.py function
    def destroy(window, self) (bgo#732614).
  - Python template not loading (bgo#732446).
  + AppData file does not validate (bgo#731844).
  + run-program: Gnome-Terminal not support --disable-factory
    argument (bgo#730314).
  + Add a warning if there is an error while getting package list.
  + anjuta installs icons in the gnome icon theme (bgo#730895).
  + Bugs fixed: bgo#734719, bgo#722197.
  + Updated translations.
- Drop anjuta-move-icons-to-hicolor.patch and
  anjuta-no-vte-no-crash.patch: fixed upstream.
* Tue Jul 15 2014 dimstar@opensuse.org
- Add anjuta-no-vte-no-crash.patch: Do not crash if VTE is not
  available.
* Tue Jul 15 2014 zaitor@opensuse.org
- Add anjuta-move-icons-to-hicolor.patch: move icons to hicolor.
  Needed after merge of themes into adwaita theme.
- Stop running icon_theme_cache_post(un) gnome in post(un), no
  longer needed due to above patch.
- Temporarly disable building of terminal plugin via commenting out
  pkgconfig(vte-2.91) BuildRequires.
* Sun Jul 13 2014 dimstar@opensuse.org
- Drop gnome-icon-theme-devel BuildRequires and gnome-icon-theme
  Requires: no longer required after the merging of the themes into
  Adwaita theme, which in turn is a dependency to GTK+ 3.0.
* Tue May  6 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Load big projects without errors and without blocking the GUI.
  + Keep the most recent message pane on the left.
  + Miscellaneous improvements to the About dialog.
  + Give reasonable default size to git dock.
  + Mark images as not translatable to keep them off translators
    radar.
  + Bugs fixed: bgo#727634, bgo#627091, bgo#727637, bgo#727633,
    bgo#727630, bgo#349733, bgo#726607.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + gdb: Disable password-prompt for gdb communication.
  + Don't set a minimum window size - just use the default.
  + Fix crash when launching nonexistant program.
  + Bugs fixed: bgo#688020, bgo#725373, bgo#723451, bgo#722989,
    bgo#723452, bgo#723449, bgo#723510, bgo#723458, bgo#723443,
    bgo#711353, bgo#723444.
  + Updated translations.
* Sun Feb 23 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Support Vala 0.24.
  + libanjuta: Set reasonable default size for preferences window
    (bgo#723444).
  + anjuta: Don't set a minimum window size - just use the default.
  + gdb: Disable password-prompt for gdb communication.
  + User help: fix a typo.
  + Fix crash when launching nonexistant program.
  + Project Wizard - Set default setting for author, email,
    version, and project directory (bgo#711353).
  + New Window action is always disabled (bgo#723443).
  + Missing image icon next to recent projects (bgo#723458).
  + teminal: Warning after closing a program started by Run ->
    Execute (bgo#723510).
  + anjuta: Should set a reasonable default window size
    (bgo#723449).
  + debug-manager: Remove weak pointer when needed.
  + file-manager: Remove weak pointer when plugin is finalized.
  + quick-open: Remove weak pointer on deactivation.
  + run-program: Remove unneeded weak pointer.
  + tools: Remove weak pointer when the context is destroyed.
  + symbol-db: Remove weak pointer when plugin is destroyed.
  + language-support-cpp-java: Remove a critical warning when
    Anjuta is closed.
  + build-basic-autotools: Remove unused idle handler.
  + project-manager: Fix critical warnings when closing Anjuta
    window if multiple windows are open (bgo#723452).
  + Updated translations.
- Drop anuta-libvala-0.24.patch: fixed upstream.
- Drop gnome-common BuildRequires: No longer needed as we do not
  carry any patches anymore.
* Wed Jan 29 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Bugs fixed: bgo#722721, bgo#722721, bgo#722721, bgo#722720,
    bgo#721534, bgo#720126, bgo#711720, bgo#721783, bgo#721782,
    bgo#722005, bgo#720969, bgo#711722, bgo#711512, bgo#708248,
    bgo#709752, bgo#708748.
  + Updated translations.
- Replace pkgconfig(neon) BuildRequires with pkgconfig(serf-1):
  Following subversions switch to serf in place of neon.
* Tue Jan 28 2014 dimstar@opensuse.org
- Switch to vala 0.24 for GNOME 3.12 target:
  + Replace pkgconfig(libvala-0.24) BuildRequires with
    pkgconfig(libvala-0.24), for the actual switch.
  + Add anuta-libvala-0.24.patch: Add support for Vala 0.24.
  + Add gnome-common BuildRequires: required, as above patch
    touches the build system and we need gnome-commons to correctly
    bootstrap the tarball, due to GNOME_COMPILE_WARNINGS.
* Mon Dec 23 2013 dvaleev@suse.com
- Do not BuildRequire valgrind for ppc64le.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + bgo#711722: C-Makefile project template broken.
  + document-manager: Fix bgo#711512.
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + git: Run diff commands after the status commands finish.
  + libanjuta/git: Render diffs one line at a time.
  + project-manager: Plural forms for "%%d elements" (bgo#707562).
  + project-wizard: Auto completion code when you click in the
    widget tree is broken (bgo#707943).
  + Updated translations.
* Mon Sep  2 2013 zaitor@opensuse.org
- Update to version 3.9.91:
  + git:
  - Fix removed files status display.
  - Expand the status view tree when all diff commands are
    finished.
  + project-manager: The 'Can not add source files' dialog is too
    long and his buttons and bottom side are out of the screen
    (bgo#501230).
  + Fix incorrect MimeType in .desktop file (bgo#706630).
  + Remove a critical warning when closing a project.
  + glade: Fix a critical warning when opening a project with a .ui
    file opened.
  + document-manager: Close all documents when closing a project.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + document-manager: Fix icon size in document manager tabs.
  + git:
  - Widget name fixes.
  - Show diffs of uncommitted changes in the status view.
  - Show stash diffs in the stash pane.
  - Don't show the command bar if the Tasks button isn't active.
  - Don't show stash numbers on diff rows.
  + libanjuta:
  - Add AnjutaCellRendererDiff.
  - Update the glade catalog.
  + libanjuta/anjuta-command-bar:
  - Resect GTK button image settings.
  - Don't use a shadow for the scrolled window.
  + symbol-db:
  - link with librt on Linux (bgo#704985).
  - Use a GtkSearchEntry for the search entry in the search view.
  + libanjuta/anjuta-file-list: Fix the help text color.
  + libanjuta/anjuta-cell-renderer-diff: Detect diff headers.
  + build: add support for libvala-0.22.
  + Use program icon on about dialog.
  + Fix column number on lines with tabs.
  + help: fix broken images.
  + Bugs fixed: bgo#689384, bgo#701419.
- Drop anjuta-vala-0.22.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as we don't carry any patch anymore.
* Tue Aug  6 2013 dimstar@opensuse.org
- Add anjuta-vala-0.22.patch: Allow building with vala 0.22.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
- Change pkgconfig(libvala-0.20) BuildRequires to
  pkgconfig(libvala-0.22) in order to perform the switch to Vala
  0.22.
- Stop passing obsolete --disable-scrollkeeper to configure.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + anjuta: Only show app-menu if supported by environment.
  + libanjuta: Make AnjutaCommandBar easier to use on small
    screens.
  + Bugs fixed: bgo#699544.
  + Updated translations.
* Tue Jul  9 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + anjuta: Add application menu.
  + git: Fix the Do Not Commit option in the Revert pane.
  + libanjuta/anjuta-entry: Don't use CSS for help text styles.
  + Keep using loaded plugin even if they are marked as disabled.
  + Register GApplication with a different name if a profile is
    used.
  + document-manager: Make use of symbol-db plugin optional.
  + language-support-python: Remove critical warnings.
  + language-manager: Support symbols in more programming
    languages.
  + Need at least glib 2.34 for g_spawn_check_exit_status.
  + dir-project: Load big project faster.
  + dir-project: Decrease project load priority to avoid blocking
    GUI.
  + am-project: data target are not distributed by default in
    automake.
  + project-manager: Add a function in the interface to remove a
    file from a project.
  + Bugs fixed: bgo#703637, bgo#702576
  + Updated translations.
* Sat Jun 22 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + sourceview:
  - fix compile warnings.
  + message-view: don't manually free private structure.
  + snippets-manager: fix compile warnings.
  + git:
  - Add a context menu to the log pane.
  - Add a context menu to the Branches pane.
  - Add a popup menu to the Remotes pane.
  - Check box action fixes in Push and Pull panes.
  - Add a popup menu to the Stash pane.
  - Fix a warning.
  + libanjuta:
  - Improve symbol-db behavior on cut, paste, undo, redo and
    when multiple files are modified.
  - Move scoped and descoped signal on AnjutaProfile object.
  - Replace AnjutaPluginDescription by AnjutaPluginHandle in API.
  - Move anjuta_profile_manager_load_profile function in
    anjuta_profile.
  - Always keep plugins in the system profile.
  - Allow to enable only a set of plugins defined in the profile
    file.
  - Keep dynamic allocation data in AnjutaPluginDescription.
  - Allow to change plugin description key from profile.
  + Allow to select different profile on the command line.
  + Add a sample custom profile keeping only the editor.
  + document-manager: Automatically open an empty file if starter
    plugin is not used.
  + symbol-db: Update symbol database on editor changes without
    saving.
  + language-support-cpp-jave: Fix memory leak.
  + Bugs fixed: bgo#701443, bgo#701207, bgo#700383
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + subversion: convert builder file to gtk+-3.0.
  + starter: guard for NULL document manager or project manager.
  + Fix deprecation warnings.
  + Bugs fixed: bgo#699323, bgo#699329, bgo#699327, bgo#699330,
    bgo#699326, bgo#698705, bgo#699316, bgo#700615, bgo#696991,
    bgo#698158, bgo#700318, bgo#694644.
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + anjuta_language_provider: add proposals() function.
  + anjuta-tabber:
  - Always use the padding of an active tab in y-direction size
    allocation.
  - don't iterate list to check if node is first/last.
  - fix calculation of region flags.
  - implement gtk_container_get_path_for_child().
  - remove call to gtk_widget_style_attach().
  - remove the total padding from total width.
  - rework size allocation.
  - take focus-padding into account when rendering focus.
  - use tab_curvature for left/right space of first/last tab.
  + dir-project:
  - check for NULL groups in dir_project_is_loaded().
  - fix compile error.
  + document-manager:
  - don't allocate AnjutaDocmanPriv ourselves.
  - don't free AnjutaDocmanPriv ourselves.
  - fix compile warning.
  - pack notebook with width 1.
  - remove margin around the document combo box.
  + git:
  - Add a stash button to the Status command bar.
  - Fix more names in the glade file.
  - Fix setting of a custom author in the commit panel.
  - Fix widget names.
  - Implement adding files by dragging them onto the status view.
  - Implement branch switching by double-click.
  - More glade file name fixes.
  - Pack the dock and the command bar together.
  - Use actions for recurring items in the glade file.
  - Use a toggle button to show and hide the command bar.
  - Widget name fixes.
  + language-support-js:
  - replace one more use of ianjuta_editor_assist_proposals().
  - use anjuta_language_provider_proposals().
  + language-support-python:
  - replace one more use of ianjuta_editor_assist_proposals().
  - use anjuta_language_provider_proposals().
  + libanjuta: Improve editor modeline support.
  + libanjuta/manuals: Update documentation sections.
  + message-view:
  - Use AnjutaCloseButton in tabs.
  - use a single box for the tab widget.
  + mk-project:
  - Ignore conditional directives in makefile.
  - Prevent a crash.
  + parser-cxx:
  - fix compilation warning.
  - use anjuta_language_provider_proposals().
  + project-wizard: Use dist_doc_DATA for documentation text files.
  + sourceview: remove filtering of single proposals matching
    pre_word.
  + symbol-db-query: change order of property installation in
    SymbolDBQuery.
  + Update doap file.
  + Use dist_doc_DATA for documentation text files.
  + Bugs fixed: bgo#680770, bgo#688611, bgo#696023, bgo#696984,
    bgo#696990, bgo#697030, bgo#698011.
  + Updated translations.
- Drop anjuta-glade.xml source: it's included in the tarball.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + git: Log path entry should be editable.
  + project-wizard: Creating new project using wizard fails due to
    license files missing (bgo#696672).
  + Bugs fixed: bgo#696023.
  + Updated translations.
- Re-add anjuta-glade.xml: bgo#696023 seems not entirely fixed.
* Tue Mar 26 2013 dmueller@suse.com
- Do not BuildRequire valgrind for aarch64.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Wed Mar 20 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + document-manager:
  - Allow to search starting from the current position.
  - Highlight search text in background.
  - Move common code in a function.
  + file-manager: make file_view_show_extended_data() more robust.
  + Fix desktop file syntax errors.
  + Fixed needlessly marked label for translation.
  + git:
  - fix up memory management of log model.
  - properly unset the log command in the case the command failed
  - Unset the log model view before refreshing the log.
  - use g_signal_connect_object() in GitLogCommand.
  - use g_signal_connect_object() to connect to commands in
    GitLogPane.
  + libanjuta: keep a ref on the AnjutaAsyncCommand when its thread
    is run.
  + Make the glade catalog an optional feature.
  + message-view: use g_type_class_add_private() to add private
    struct.
  + parser-cxx: use g_signal_connect_object() to connect to query
    signals.
  + sourceview:
  - add checks to SourceviewIO that the parent Sourceview is
    alive.
  - don't take extra refs during open/save.
  - keep a separate reference to AnjutaShell in SourceviewIO.
  - move all construction of Sourceview into constructed.
  - only cancel open operations when closing editor.
  - only update stored etag if save was succesful.
  - use g_signal_connect_object() to connect to io signals.
  + symbol-db: don't allow or set null scope_definition_id and
    scope_id.
  + Updated translations.
- Pass --enable-glade-catalog to configure to ensure the catalogs
  are being installed.
- Add anjuta-glade.xml to sources, which is missing in the tarball.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Add new quick-open plugin.
  + am-project: Fix a crash when changing target properties.
  + Anjuta:
  - Saved dock positions not applied when opening a project
    (bgo#688609)
  - Make sure the starter widget is visible on startup.
  + build-basic-autotools:
  - don't let build directory button expand.
  - Fix selection of build directory.
  + class-gen:
  - Always generate GObject private structure.
  - generate license the same way as project-wizard.
  - output filename instead of project name before copyright.
  + devhelp: Port to webkitgtk2.
  + document-manager:
  - connect to toplevel SearchBox keypress to handle closing.
  - Save search box settings.
  + file-manager:
  - Add option for showing the currently edited file in the file
    manager.
  - Add "Show in File manager" action to document popup.
  - Enable typeahead search.
  + glade: Add a menu item for glade properties dialog.
  + indentation-c-style: enable the plugin for IDL files.
  + jhbuild:
  - Extract libdir from newly added JHBUILD_LIBDIR environment
    variable.
  - Translate error messages.
  + language-support-cp-java: fix crasher when swapping
    header/source
  + libanjuta:
  - Add basic tests for AnjutaCompletion.
  - Add new AnjutaCompletion object for prefix matching.
  - Avoid the name Anjuta in libanjuta messages (bgo#693916)
  + parser-cxx:
  - remove unused ParserCxxAssistContext
  - use AnjutaCompletion instead of deprecated GCompletion
  + patch: Replace deprecated GtkTable by GtkGrid
  + project-import:
  - Open a directory with Anjuta.
  - Try to fill project name automatically in import project
    dialog
  + project-manager: Remove New Library menu item.
  + project-wizard: move license templates to data/
  + sourceview:
  - connect settings notifications with g_signal_connect_object()
  - Fix wrong assignment when saving markers
  - mark clearing of buffer as a not undoable action
  - use etag to only emit "changed" when file was externally
    modified
  - use G_PRIORITY_DEFAULT for IO
  - use gtk_widget_preferred_size instead of gtk_widget_size_request
  + starter: Fix a warning
  + symbol-db:
  - fix compile warnings
  - fix symbols view label box to be horizontal
  + Updated translations.
- Replace pkgconfig(libvala-0.18) BuildRequires with
  pkgconfig(libvala-0.20), following the GNOME 3.8 release plans.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + file-loader:
  - Fix leak of GtkRecentInfos in the RecentChooserMenu.
  - file-loader: Fix leak of plugin names in sort_wizards()
  + file-manager: Fix compile warning.
  + git: Fix destruction of GitLogPane.
  + libanjuta:
  - Actually free stuff in AnjutaPkgConfigChooser::finalize.
  - Add "document-[added|removed]" signals to
    IAnjutaDocumentManager.
  - Allow to set indentation and tab size separately
  - Clean up and bug fix in plugin manager
  - Fix a few compiler warnings
  - Fix IAnjutaFile::opened signal documentation.
  + project-manager:
  - Allow to change project backend
  - Display current project backend
  - Fix leak of the nodes GList in gbf_project_view_update_tree().
  + run-program: Default to Yes in "The program is already running"
    dialog.
  + snippets-manager: Fix faulty assertion in snippets_db_dispose().
  + sourceview:
  - Add marks to an unloaded document the same way we reload
    marks.
  - Detect that a ifile_open() is a reload and save marks and
    position.
  - Don't check if objects are not NULL before calling
    g_clear_object().
  - keep ref on SourceViewIO during call to
    input_stream_read_async().
  + starter: Fix leak of GtkRecentInfo.
  + symbol-db:
  - Add update_flag to the symbol unique constraint.
  - Fix leaks
  - Fix "parenthesis" typos
  - rename sdb_engine_get_tuple_id_by_unique_name4()...
  - When updating a symbol try to update the closest one.
  + Updated translations.
* Sun Jan  6 2013 zaitor@opensuse.org
- Update to version 3.7.3:
  + Added keywords in desktop file.
  + anjuta:
  - Fix destruction of the AnjutaUI instance.
  - Fix destruction of AnjutaPreferences instance.
  - Unload all plugins before closing a window.
  - Remove "exiting" signal from AnjutaShell.
  + anjuta-plugin-handle: Use g_hash_table_remove_all instead of
    g_hash_table_foreach_remove.
  + am-project: Change the "Dependencies loop in variables"
    warning to a debug print.
  + build: disable -Werror to workaround flex(1) issue.
  + build-basic-autotools:
  - Disconnect all signals on editors when the plugin is
    deactivated.
  - Remove idle for updating indicators when plugin is
    deactivated.
  + document-manager:
  - Remove autosave timeout when the plugin is deactivated.
  - Fix disconnection of GtkNotebook "switch-page" signal.
  + file-manager:
  - Keep a weak reference to the IAnjutaVcs object in FileModel.
  - Unref the FileModel reference when the FileView gets
    finalized.
  + git: Fix compile warnings.
  + glade: Add toggle buttons for margin and align editing.
  + indentation-c-style: Fix logic error.
  + libanjuta: Set "relative-path" property of AnjutaFileDropEntry
    as readwrite.
  + plugin-manager:
  - Fix dependents checking on wrong object in should_unload().
  - Don't destroy available_plugins order in
    populate_plugin_model().
  - Clean up memory management.
  - Directly use anjuta_plugin_deactivate in unload_all_plugins()
  + profile-manager: Add new close() function.
  + project-wizard:
  - Allow to start a new project from the command line.
  - Remove trailing spaces.
  - Remove compilation warnings.
  - hide breakpoints and watches windows on new project
    bgo#616728.
  + run-program:
  - Keep a weak reference to the IAnjutaTerminal we run the
    program in.
  - Fix a crash when destroying the plugin.
  + sourceview: Don't store the builder for the preferences in a
    global variable.
  + symbol-db:
  - Keep a reference to the SymbolDBQuery when running it in a
    thread.
  - Use a vertical box for the search view.
  - Remove buffer update timeout when plugin gets deactivated.
  + Updated translations.
* Sat Nov 24 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + anjuta: Allow to abort loading of a session
  + anjuta-window: Don't call gtk_widget_show_all when setting up
    widget.
  + debug-manager:
  - Fix accessing of invalid tree models.
  - use g_spawn_sync() instead of fork() and waitpid()
  + document-manager:
  - Add search_box to document manager box directly.
  - Fix various compile warnings.
  - hide search box when pressing escape inside the document
    widget.
  - Never disable "find in files" action.
  - Remove obsolete code for tabbing between documents.
  - Show dirty character "*" and "[read-only]" in combo filename.
  - Support showing open documents in a combobox.
  - Update combo filenames when the project changes.
  - use on_close_file_activate() when closing file using combo
    close button.
  + file-manager: Fix invalid unref of NULL pointer.
  + Fix compile errors regarding undeclared functions.
  + git:
  - Fix assertion when running g_hash_table_unref() on a NULL
    pointer.
  - Fix assertion when running g_signal_handlers_disconnect on
    already destroyed widget.
  - Fix bgo 687145 - Critical warning when switching git pane
  + glade:
  - Fix the images in the palette toggles used for choosing the
    edit mode.
  - Fix the palette not being shown.
  + indentation-c-style:
  - Add option whether paranthesis alignment should only use
    spaces.
  - be more picky when completing braces.
  - Change plugin.c modeline to spaces
  - Enable the plugin for JavaScript source files.
  - Fix get_line_indentation().
  - Fix modeline in plugin.c
  - Fix "parenthesis" typos
  - remove java_indentation() method
  - Rename action group to "C Indentation" and remove it on
    deactivation.
  - Update preferences UI file to gtk+-3
  - When removing opening bracket also remove the closing one.
  + indentation-python-style: Rename action group to "Python
    Indentation".
  + language-support-cpp-java: Remove
    org.gnome.anjuta.plugins.cpp.gschema.valid from git
  + language-support-vala: Don't clean config.vapi
  + libanjuta:
  - Improve documentation of AnjutaSession
  - use g_spawn_sync instead of fork() and waitpid()
  + project-wizard: Fix vala ui path (bgo#686718)
  + python:
  - Auto-completion causes a segfault in Anjuta 3.6.1
    (bgo#687646)
  - Fix crash during auto-indentation
  + sourceview: don't emit change events after doing an undo
  + Fixed compile warnings and a real bug in the gdbmi plugin
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + am-project:
  - Avoid critical warnings when a group does not have a
    Makefile.am
  - Double click on folder in project view open properties window
    (bgo#681050)
  - Folder properties dialog can't be close with ESC (bgo#681051)
  - Project browser is not updated when files are added or removed
    (bgo#683728)
  - Adding a "Miscelaneous Data" objective ignores the given name
    (bgo#684770)
  - Check a copy of anjuta project in regression instead of the
    real project
  - Do not store files as binary in anjuta shar archive used in
    regression test
  + anjuta:
  - Do not use GDL members deprecated in version 3.6
  - Move command line parsing in AnjutaApplication
  - Remove custom filtering for debugging message as this is
    provided by GLib >= 2.32
  - Rename AnjutaApp as AnjutaWindow
  - Rename Anjuta as AnjutaApplication
  + build-basic-autotools:
  - Configuration name combo box should be editable
  - Fix alignment of some text broken by the previous patch
  - Update environment variables when the build configuration is
    changed
  + build: anjuta-3.5.91 fails to configure due to ac_ct_CXX check
  (bgo#684758)
  + glade: Fix make file some files were not installed
  + jhbuild:
  - new plugin to build/run program inside the jhbuild environment
  - Provide a fallback for G_DEFINE_QUARK to allow compilation
    with GLib 2.32
  + run-program: use AnjutaEnvironmentEditor instead of implementing
  our own version.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + indentation-c-style:
  - be more picky when completing braces.
  - remove java_indentation() method
  - When removing opening bracket also remove the closing one.
  + sourceview: don't emit change events after doing an undo
  + build-basic-autotools:
  - Configuration name combo box should be editable
  + Do not use GDL members deprecated in version 3.6
  + Updated translations.
* Fri Oct 19 2012 zaitor@opensuse.org
- Update to version 3.6.1:
  + Anjuta crashes when switching git branches of the current
    project on the commandline bgo#681073.
  + Updated translations.
* Thu Sep 27 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + project-manager:
  - Support for calling make check
  - Support for subdirectories in project groups
  - Crash fixes
  + git:
  - Git Tasks dock is only shown when the Git dock is active
  - The Status view is the first view shown in the Git dock
  - Status view works with git 1.7.10 and newer
  + symbol-db:
  - Various crash and infinite loop fixes
  + sourceview:
  - Use common indentation settings
  + Bugs fixed: bgo#680401, bgo#672692, bgo#675877, bgo#678695,
    bgo#679827, bgo#680136, bgo#680554, bgo#680559, bgo#680555,
    bgo#680657, bgo#679767
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-devel:
  following upstreams port to the new documentation infrastructure.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Bugs fixed: bgo#679767, bgo#680401, bgo#682501.
  + Updated translations.
- Drop anjuta-includes.patch: fixed upstream.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + class-inheritance, code-analyzer: Remove plugins that don't
    work or aren't built
  + document-manager:
  - Entry of find in files doesn't get focused (bgo#680554)
  - Escape key does not dismiss Find in Files panel (bgo#680555)
  - Find in Files does not scroll to top of results (bgo#680559)
  - Only use in project files
  - Unify focus handling
  + git: Only show the Git Tasks menu when the Git window is active
  + Several other code changes.
  + Several improvements to the FAQ.
  + Build fixes.
  + Bugs fixed: bgo#680136, bgo#680466, bgo#680657.
- Drop pkgconfig(libgraph) BuildRequires: it was only needed for
  plugins that got dropped.
- Add anjuta-includes.patch: Fix build with gtksourceview 3.5.3.
* Fri Aug  3 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + libanjuta: Fix memory corruption in AnjutaPkgConfig
    (bgo#679827)
  + Small fixes to cxxparser (including bgo#679772).
  + Improve calltips in vala plugin
  + Updated translations.
* Thu Aug  2 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + build-basic-autotools: bgo#674863: No easy way to call make
    check
  + git: Show the Status pane on plugin load
  + indentation: Use Indentation as name for all indentation
    preferences
  + project-wizard:
  - Explicitely use 3.0 as interface version for ui files
    (bgo#675877)
  - Make sure no template requires gtk+ 2.12 anymore
  + symbol-db: Ignore files with unknown language (bgo#678695)
  + vala support: update to Vala 0.18
  + Split language-support-cpp-java and language-support-python
    plugin in an indentation part and a new language-support part
  + Several other code changes.
  + Build fixes.
  + Bugs fixed: bgo#675118, bgo#676811.
  + Updated translations.
- Replace pkgconfig(libvala-0.16) BuildRequires with
  pkgconfig(libvala-0.18): Use vala 0.18.
* Wed Aug  1 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Use common settings for indentation in several plugins.
  + Fix autoindentation after line wrapping
  + libanjuta:
  - Allow to define common settings in plugin preference page
  + am-project:
  - Include project files as sources in the project tree
  - Allow to create the root group in an empty project
  - Allow to have sub directories in a group
  - Do not expand variable in target and group flags
  - Expand variables in source names
  - Fix multiple crashes
  + project-manager:
  - The target advanced options window should remember its size
    (bgo#594912)
  - Display group name containing sub directories
  + sourceview: Correctly implement popup-menu (bgo#672692)
  + Several other code changes.
  + Minor build system fixes.
  + Updated translations.
* Tue Jul 31 2012 dimstar@opensuse.org
- Update to version 3.4.4:
  + libanjuta:
  - Fix memory corruption in AnjutaPkgConfig (bgo#679827)
  + document-manager:
  - entry of find in files doesn't get focused (bgo#680554)
  - Find in Files does not scroll to top of results (bgo#680559)
  - Escape key does not dismiss Find in Files (bgo#680555)
  + cxxparser:
  - avoid infinite loop (bgo#679772)
  - improved code checks to avoid leaks
  - fixed warning on query field retrieving
  + symbold-db:
  - Don't crash if project was moved to another location
  - Ignore files with unknown language (bgo#678695)
  + glade: Fix check order of editor on member add (bgo#676811)
  + Updated translations.
* Wed May 23 2012 zaitor@opensuse.org
- Update to version 3.4.3:
  + This release fixes a broken tarball that was distributed for
    3.4.2.
  + configure: Detect python more robust.
  + Updated translations.
* Thu May 17 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + project-wizard:
  - Make sure no template requires gtk+ 2.12 anymore
  - Explicitely use 3.0 as interface version for ui files
    (bgo#675877)
  + Updated translations.
* Sun Apr 29 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Fix a typo in the code-analyzer plugin name
  + sourceview: Correctly implement popup-menu (bgo#672692)
  + Updated translations.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Various bug fixes and code changes.
  + Updated translations.
* Mon Mar  5 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Automatically add a callback when user double-clicks a signal
    in the glade signal editor (bgo#670149).
  + Documentation improvements.
  + Several other code changes.
  + Bugs fixed: bgo#627089, bgo#662955, bgo#670483, bgo#670537,
    bgo#670656, bgo#670789, bgo#670830.
  + Updated translations.
- No longer delete generated .c files: they are no longer part of
  the tarballs.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + What's new:
  - Find in files is back!
  + Implement automatic member declaration and initialization for
    widgets in the glade plugin.
  + Save relative resources instead of absolute paths in session
    files.
  + Fix .desktop file so that gnome-shell recognizes anjuta.
  + Add support  for vala 0.15/0.16.
  + Various other code changes.
  + Improved documentation.
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Drop anjuta-vala-0_16.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to autogen.sh: those
  were only needed for the above patch.
* Tue Jan 17 2012 dimstar@opensuse.org
- Update to version 3.3.4:
  + Small improvements in search (bgo#665945).
  + Several improvements in generated files from project-wizard.
  + language-support-cpp: Code completion now closes parentheses
    (bgo#633341)
  + symbol-db: Fix symbol update when switching branches
    (bgo#664413)
  + Various other code changes.
  + Other bugs fixed: bgo#667903, bgo#666621, bgo#666966.
  + Updated translations.
* Fri Jan 13 2012 dimstar@opensuse.org
- Replace pkgconfig(libvala-0.14) BuildRequires with
  pkgconfig(libvala-0.16) in order to build against vala 0.15/0.16.
- Add anjuta-vala-0_16.patch: Fix build with libvala-0.16
- Add gnome-common BuildRequires and call to autogen.sh, as the
  above patch touches the build system.
- Delete .c files that are auto-generated from .vala files to
  ensure they are generated with the right vala compiler.
- Add vala BuildRequires: as we drop the shipped generated .c
  files, we need to rebuild them during our build.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Fix various crashes (including bgo#665082, rh#532290,
    rh#757236).
  + Several improvements to git support.
  + Several improvements to vala support.
  + Fix memory leaks.
  + Ship files missing in 3.3.2.
  + Various other code changes.
  + Other bugs fixed: bgo#641079, bgo#646695, bgo#656761,
    bgo#666321, bgo#666336, bgo#666448, bgo#666482.
  + Updated translations.
- Drop gnome-shell-extension-template.tar.bz2: the files are in
  the tarball now.
* Fri Dec  9 2011 dimstar@opensuse.org
- Split typelib files into typelib-1_0-Anjuta-3_0 subpackage.
- Add typelib-1_0-Anjuta-3_0 Requires to devel subpackage.
* Sat Nov 26 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Add template for Gnome Shell Extension (bgo#661299).
  + Bugs fixed: bgo#648934, bgo#662526, bgo#663016, bgo#663385,
    bgo#664058, bgo#664263, bgo#645212, bgo#629769, bgo#658788,
    bgo#662960.
- Inject gnome-shell-extension-template.tar.bz2 into build system,
  as the tarball misses those files. See bgo#664829.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Integrate fixes from 3.2.1.
  + Bugs fixed: bgo#610371, bgo#633284, bgo#653274, bgo#659563,
    bgo#662526.
* Wed Oct 19 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Bugs fixed: bgo#660841, bgo#653652, bgo#660061, bgo#660065,
    bgo#661511.
* Wed Oct  5 2011 vuntz@opensuse.org
- Apply shared library packaging policy (bnc#690233):
  + Create libanjuta-3-0 subpackage.
  + Change anjuta Requires in devel subpackage to libanjuta-3-0.
  + Move calls to /sbin/ldconfig from %%post/%%postun of main
    subpackage to those of the libanjuta-3-0 subpackage.
  + This became more important as gtkpod now uses this library and we
  don't want to have gtkpod depend on the whole anjuta application.
* Sun Sep 25 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fixed make distcheck: FAQ, autotests, etc.
  + Updated translations.
- Drop hack to install anjuta_logo.png properly during %%install:
  fixed upstream.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Bugs fixed: bgo#656470, bgo#658229, bgo#658262, bgo#566700,
    bgo#654320, bgo#655295, bgo#658903, bgo#654463.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + More improvements in vala plugin
  + Fix up problems with gtk+ 3.0
  + Bugs fixed: bgo#638525, bgo#657491, bgo#657513, bgo#657589,
    bgo#655756, bgo#656123, bgo#657590, bgo#657022.
- Remove unneeded call to mime-info-to-mime in %%install.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Some seldom used debugger menu items were removed
  + A lot of fixes to the vala support
  + vala-0.14 (>= 0.13.3) is now required
  + Bugs fixed: bgo#656584, bgo#642187, bgo#657023, bgo#566704,
  bgo#652047, bgo#656585, bgo#657134, bgo#653259.
- Drop anjuta-support-libgda-5.0.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh
  now that there is no patch requiring this.
* Sat Aug 13 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Bugs fixed: bgo#654881, bgo#651151, bgo#654502, bgo#655743,
    bgo#655998, bgo#655584.
- Drop anjuta-gtk_hv_box.patch: Fixed upstream.
- Add a hack to install anjuta_logo.png properly in the manual.
* Tue Aug  2 2011 dimstar@opensuse.org
- Add anjuta-gtk_hv_box.patch: Stop using deprectaed GtkHBox and
  GtkVBox.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Bugs fixed: bgo#654502, bgo#646410, bgo#654073, bgo#654124,
    bgo#654445, bgo#654099, bgo#654100, bgo#654559, bgo#654092,
    bgo#654095, bgo#654560, bgo#631157, bgo#654455.
- Drop anjuta-libvala-0.14.patch: fixed upstream.
* Tue Jul 12 2011 dimstar@opensuse.org
- Add anjuta-libvala-0.14.patch: Allow building against
  libvala 0.14. Patch sent upstream as bgo#654502.
- Change pkgconfig(libvala-0.12) BuildRequires to
  pkgconfig(libvala-0.14)
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Various improvements in the project wizard
  + Git usability improvements
  + Auto-completion for Gtk.Builder objects in python plugin
  + More mallard documentation
  + Bugs fixed: bgo#649107, bgo#651212, bgo#312667, bgo#588952,
    bgo#590323, bgo#645516, bgo#646073, bgo#646192, bgo#652773,
    bgo#652778, bgo#653364, bgo#647403.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Autocompletion for builder objects in python
  + Improvements in autotools backend
  + Bugs fixed: bgo#475261, bgo#651670, bgo#651285, bgo#569994,
    bgo#644047, bgo#588757, bgo#640470, bgo#642784, bgo#648571,
    bgo#650930, bgo#652017, bgo#651212.
- Add bison and flex BuildRequires: those were needed before, but
  we failed to notice because of a bug in the configure script.
* Tue Jun  7 2011 dimstar@opensuse.org
- Build against libgda 4.99/5:
  + Add anjuta-support-libgda-5.0.patch: support building against
    libgda 5.0 and libgda 4.0 and add call to gnome-autogen.sh.
  + Replace pkgconfig(libgda-4.0) BuildRequires with
    pkgconfig(libgda-5.0).
* Sat Jun  4 2011 badshah400@gmail.com
- Enabled building glade-catalog-anjuta for use with glade for
  gtk+3
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 3.0.2.0:
  + Fix "Redo" in glade plugin
  + Make tabs look less ugly
  + Bugs fixed: bgo#644047, rh#705958
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1.0:
  + Bugs fixed:
  - bgo#563856: generic Vala project type.
  - bgo#645199, bgo#646530, bgo#588387, bgo#645659, bgo#645695,
    bgo#645965, bgo#648361, bgo#648571.
* Wed Apr 27 2011 vuntz@opensuse.org
- Add gobject-introspection-devel BuildRequires to build
  introspection support.
- Remove now unneeded BuildRequires: libwnck-devel.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: devhelp-devel, gdl-devel, graphviz-devel,
    gtksourceview-devel, libgda-4_0-devel, libgladeui-1_0-devel,
    libneon-devel.
  + New ones: glib-2.0, gdk-pixbuf-2.0, gdl-3.0, gladeui-2.0,
    gtk+-3.0, gtksourceview-3.0, libdevhelp-3.0, libgda-4.0,
    libgraph, libgvc, libxml-2.0, neon.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0.0:
  + Bugs fixed: bgo#645470, bgo#645557, bgo#646530.
  + Updated translations.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.91.92.0:
  + Lots of little fixes on the templates
  + Bugs fixed:
  - bgo#565275: Quick Search should be able to search backward
  - bgo#565276: highlight all matches in Quick Search
  - bgo#643379, bgo#307515, bgo#336856, bgo#638134, bgo#645311,
    bgo#644050, bgo#643621, bgo#644595, bgo#645049, bgo#645076,
    bgo#570912, bgo#644294.
- Changes from version 2.91.91:
  + New:
  - Signal dragging support for Vala
  - Improved C++ signal dropping features
  - Regular expression inline search
  + Bugs fixed: bgo#623735, bgo#638836, bgo#336856, bgo#565275,
    bgo#565276, bgo#568047, bgo#638134, bgo#643205, bgo#644014,
    bgo#640545, bgo#642763, bgo#627105, bgo#642749, bgo#643707,
    bgo#644050, bgo#636410, bgo#639440, bgo#643245, bgo#643828,
    bgo#641331.
- Changes from 2.91.90:
  + New:
  - Signal dragging support for python
  - Glade usuability fixes
  - New inline search/replace
  + Bugs fixed:
  - bgo#530060 Have a "replace all" option in search and replace.
  - bgo#569992 support makefiles named GNUmakefile.am
  - bgo#553772, bgo#568047, bgo#631260, bgo#633786, bgo#642647,
    bgo#642719, bgo#638787, bgo#642763, bgo#516685, bgo#549440,
    bgo#565358, bgo#566248, bgo#637981, bgo#640969, bgo#641181,
    bgo#642640, bgo#642750, bgo#570912, bgo#642723.
- Changes from version 2.91.6:
  + New:
  - Support for dragging signals from glade into the code (C
    only).
  - Improvements in project-manager
  - More features in git-plugin
  + Bugs fixed:
  - bgo#618142 Anjuta Snippets Plug-in
  - bgo#638506, bgo#639786, bgo#640277, bgo#627131, bgo#639795,
    bgo#638980, bgo#608578, bgo#611206, bgo#615990, bgo#616041,
    bgo#618617, bgo#638368, bgo#639342, bgo#640348, bgo#640726,
    bgo#581613, bgo#639093.
- Changes from version 2.91.5:
  + Updates:
  - Glade integration is working again and far more stable
  - Devhelp plugin is here gain
  - New class generation for Vala, Python and Javascript
  - New artwork
  - Comment/Uncomment feature for C/C++
  - Various improvements in vala support
  + Bugs fixed:
  - bgo#637699 JavaScript wizard
  - bgo#638228, bgo#638252, bgo#511000, bgo#638532, bgo#637774,
    bgo#638534, bgo#616426, bgo#625399, bgo#633018, bgo#637695,
    bgo#638097, bgo#638347, bgo#638830, bgo#638878, bgo#638034,
    bgo#638524.
- Changes from version 2.91.4:
  + New:
  - Project Manager: Lots of work improving the new project
    manager.
  - Git Shell: More panes for git features
  + Bugs fixed: bgo#636665, bgo#609213, bgo#636667, bgo#637249,
    bgo#621424, bgo#636312, bgo#619592, bgo#636084, bgo#636666,
    bgo#636668, bgo#584060.
- Changes from version 2.91.3:
  + New:
  - Git Shell: Git interface has changed to be context sensitive
  - Project Manager: New project manager landed with much better
    capabilities.
  - clang-analyzer: New plugin to use the clang analyzer
  + Bugs fixed: bgo#615345, bgo#631213, bgo#633112, bgo#633911,
    bgo#635121, bgo#635795, bgo#631521.
- Changes from version 2.91.2:
  + New:
  - Everything works with gtk+-3.0 now. gconf replaced with
    GSettings, etc.
  - Switch to enable/disable modeline detection
  - Automatic completion of comments with "*"
  + Bugs fixed:
  - bgo#625903: Port to GSettings
  - bgo#600407, bgo#627105, bgo#577595, bgo#625978, bgo#631952,
    bgo#633661.
- Dropped now unneeded BuildRequires: gconf2-devel,
  libunique-devel.
- Replace vte-devel BuildRequires with pkgconfig(vte-2.90) and
  pkgconfig(vala-0.10) with pkgconfig(libvala-0.12).
- Disable glade3-catalog-anjuta subpackage with a
  build_glade_catalog define, until we have a gtk3-powered glade.
- Remove hack to fixup permissions of documentation files in
  %%install.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Changed the explicit <= Obsoletes for the -doc package to <.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Drop doc subpackage as it contained developer doc that should be
  in the devel subpackage.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.32.1.1:
  + bgo#636665: .vapi file not distributed
  + bgo#636312: double click fails to select entire word if it
    contains _ or digits
  + bgo#633018: fix crash happening because misuse of
    xmlCleanupParser
  + lp#448126: "Report bugs" menu entry does not work
- Add a hack to change permissions of some documentation files, so
  that they are non-executable.
- Pass --disable-schemas-install to configure, to avoid some errors
  during make install.
* Fri Nov 19 2010 vuntz@opensuse.org
- Change vala-devel BuildRequires to pkgconfig(vala-0.10)
  BuildRequires as anjuta really does need the vala library (not
  the vala compiler).
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.32.1.0:
  + bgo#621916: language-support-cpp-java: check for brace
  + bgo#633042: libanjuta: Sensitivity off 'ok' button on the
    project import dialog
  + language-support-cpp: Don't show duplicated results in
    autocompletion
  + bgo#633661: build: vala support is automagic
  + bgo#633112: language-support-cpp-java: Smart Brace Completion
    Quotation Mark Crash
  + bgo#631223: python-support: autointention causes anjuta to hang
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-anjuta subpackage. Part
  of bnc#637694.
- Update summaries and descriptions.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0.0:
  + bgo#630460: Fix PackageKit integration
  + project-wizard: Update default ui file to use gtk+-2.16
  + Updated translations.
- Add sqlite3-devel BuildRequires: it used to work because it was
  a dependency of libgda-devel, but we need it implicitly.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 2.31.92.0:
  + python-loader: bgo#628975: error in python loader .plugin
  + sourceview: bgo#626541: Crash when saving to unavailable
    location
  + bgo#628397: Fix anjuta-idl-compiler to keep typedef comments
  + bgo#628397: gir build error
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91.0:
  + More updates to the vala support
  + Bugs fixed:
  - libanjuta: bgo#622922: migrated to GDBus
  - pm: bgo#626690: wrong project clean on new-project
  - project-wizard: bgo#627595: Ambiguous strings for translation
  - symbol-db: bgo#622340: Tried to close project and Anjuta crashed
  - language-support-python: bgo#627437: couldn't find python rope.
  - bgo#627648: Add IDE to Categories in .desktop file
  - bgo#628099: Remove markup from translatable strings
  - bgo#628286: Fix introspection build when builddir != srcdir
  - bgo#628285: Don't distribute the .gir files
  + Updated translations.
- Do not set GenericName, Comment and Categories in .desktop file:
  they're already right in the upstream one.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90.0:
  + Python is now fully supported
  + Initial support for python plugins
  + Snippets plugins from GSoC
  + Bugs fixed:
  - project-wizard: bgo#625434: remove cvsignore from templates
  - python-support: bgo#626950: Anjuta crash with python support
  - build-basic-autotools: bgo#626562: crash refusing to clean
    the configuration
  - symbol-db:
    . bgo#622529: Crash when trying to open a non-writable
    project
    . bgo#616560: Symbol views do not display names containing
    especial chars correctly
  - manual: Fixed mailing list adress (bgo#625588)
  - language-support-vala: bgo#626306 Symbol completion doesn't
    work with "this."
  - libanjuta: Increase launcher buffer size (bgo#624700)
  - class-gen: add missing include (bgo#626265)
  - Add PyGTK project template. Fixes bgo#608304.
  + Updated translations.
- Drop patches included upstream:
  + anjuta-fix-warning.patch
  + anjuta-old-glade3.patch
* Sun Aug  8 2010 vuntz@opensuse.org
- Add explicit gconf2-devel BuildRequires.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6.1:
  + Bugs fixed: bgo#625964, bgo#621919
- Changes from version 2.31.6:
  + Updated:
  - Debugger is now much more polished
  - Project wizard shows better package chooser
  + Bugs fixed: bgo#625841, bgo#625604, bgo#625605, bgo#625350,
    bgo#558954, bgo#624660, bgo#515395, bgo#598187, bgo#624091,
    bgo#516112
- Changes from version 2.31.5:
  + New:
  - Debugger supports pretty-printing now
  + Updated:
  - More work on the symbol database code quality and performance
  + Bugs fixed: bgo#623754, bgo#623944, bgo#494292, bgo#617323,
    bgo#612453, bgo#622706, bgo#617472, bgo#622526, bgo#619253,
    bgo#621678, bgo#622139, bgo#621512, bgo#620927, bgo#620664
- Changes from version 2.31.3:
  + New:
  - language-support for Vala
  + Updated:
  - Symbol database is super fast now
  - Glade plugins was cleaned a lot and doesn't spit warnings
    anymore
  + Bugs fixed: bgo#618273, bgo#586428, bgo#618955, bgo#620209,
    bgo#610934, bgo#572754
- Changes from version 2.31.2:
  + New:
  - class-inheritance is included using libfoocanvas
  + Bugs fixed: bgo#616810, bgo#618314, bgo#617433, bgo#615429,
    bgo#615428
- Changes from version 2.31.1:
  + New:
  - Symbol-db tree model with direct database access. This brings
    faster a faster and more up-to-date symbol tree
  + Bugs fixed: bgo#616780, bgo#616739, bgo#616503, bgo#616435,
    bgo#550027, bgo#586689, bgo#613962, bgo#614906, bgo#614408,
    bgo#500962, bgo#611834, bgo#613118
- Add vala-devel BuildRequires to build vala support.
- Add anjuta-old-glade3.patch to not require a glade3 version we
  won't have this cycle.
- Add anjuta-fix-warning.patch to add a missing include that breaks
  the build.
* Fri Jul 23 2010 dimstar@opensuse.org
- Add libgda-sqlite Requires to fix crash on startup with the
  symbol-db plugin (bnc#624924).
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Apr 28 2010 dimstar@opensuse.org
- Update to version 2.30.1.0:
  + Bugs fixed: bgo#611834, bgo#600083, bgo#614936, bgo#614932,
    bgo#614933, bgo#614928, bgo#614751, bgo#615596, bgo#615718,
    bgo#615341, bgo#616503, bgo#616740
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0.0:
  + git: Free the log message for merges at the right time
  + Makefile.am missing libxml flags in some plugins (bgo#613559)
  + macro: #613118 - Please fix escaping of UTF-chars in ui file
  + project-wizard: JS template support and require GJS 0.6
  + build: bgo#612959 - Anjuta crashes when clicked 'Compile'
  + language-support-cpp-java: Avoid duplication of local symbols
    in project search
  + language-support-cpp-java: Fixed some undo problems with
    indentation
  + sourceview: bgo#567029 - underline warnings/errors using
    user-selected message colors
  + starter: Add tooltip for recent projects.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92.0:
  + Stabilisation fixes with autocompletion
  + Performance work
  + Bugs fixed:
  - bgo#567689: Shortcuts grabbed all components of anjuta
  - bgo#566194: Garbage in the message pane for messages with
    bold font
  - bgo#611204: sourceview: Don't block F7 shortcut
  - bgo#608499: language-support-cpp-java: Better expression
    parsing
  - project-wizard: Added back translatable-strings.h until
    bgo#610934 is fixed
  - bgo#609190: preferences: fix preferences registration for
    recent gtk+ versions
  - bgo#606596: project-wizard: Javascript template doesn't make
    sense
  - bgo#605050: fm: Saving a file duplicates its entry in File
    Manager
  - bgo#611933: build-basic-autootls: Get make targets for files
    from language-manager plugin
  - bgo##611312: Make manual page up-to-date
- Changes from version 2.29.91.0:
  + Support for Vala symbols in the symbol-db
  + Bugs fixed:
  - bgo#609227: language-support-cpp-java: autocompletion problem
    (and some memory leaks)
  - bgo#550715: Smaller icons in plugin list.
  - bgo#610397, bgo#610404: language-support-cpp-java: reapplied
    previous commit.
  - bgo#610404: symbol-db: added cancel logic to search command.
  - bgo#582726: starter: Loading file from command-line/nautilus
    puts starter page in front of file
  - bgo#582717: project-import: 'Create Folder' button not
    applicable in 'New From Existing Sources' file chooser dialog
* Mon Feb  8 2010 captain.magnus@opensuse.org
- Update to version 2.29.90.0:
  + bgo#608701: Compiler warnings
  + bgo#608396: Crash while refreshing a buffer with some
    breakpoints
  + Several fixes in symbol-db and language-support-cpp-java
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6.0:
  + Features:
  - Packagekit integration
  - Project manager supports a simple "Directory" project now
    which allows to handle project that either don't use automake
    or where the automake parser can detect the files correctly.
  + Bugs fixed:
  - bgo#541687 - selecting properties of executable with mouse
  - bgo#606801 - Bad translation error + GTKmm Project error
  - bgo#572754 - Replace deprecated GTK_OBJECT_TYPE with
    G_OBJECT_TYPE
  - bgo#601750 - Tooltip evaluation doesn't respects mouse
    position
  - bgo#605060 - Single-step highlighting works only for the
    first-opened project
  - bgo#607415 - Anjuta creates lots of random directories
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5.0:
  + Features:
  - Completion for ., ->, and :: in C/C++
  + Bugs fixed:
  - bgo#605952 - Some small fixes for symbol-db
  - bgo#566982 - don't autocomplete inside string or comment
  - bgo#586457 - Implement ianjuta_editor_cell_get_attribute()
    properly
  - bgo#605763 - No file found while adding a simple c++ class
  - bgo#605730 - completion "." "->" are not shown
  - bgo#606069 - Anjuta won't attach to process to debug it
  - bgo#559876 - Can't add python file source code to Project
    > Add source code
  - bgo#565191 - 'add project target' is mostly broken
  - bgo#566209 - "generate inhertances..." progress bar doesn't
    disappear
  - bgo#605343 - fix build warnings
  - bgo#605306 - Add missing include to fix build
- Remove anjuta-build-fix.patch. Fixed upstream
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 2.29.4.0:
  + Features:
  - Javascript support
  - Support for parsing expressions allowing member completion
  - Improved autocopletion support using GtkSourceCompletion
    support in GtkSourceview master
  + Bugs fixed:
  - bgo#597318 - Anjuta terminal crashes X
  - bgo#597815 - Crash due to malformed UI definition file
  - bgo#599532 - plugin.c: missing call to fclose
  - bgo#600924 - misc. build fixes for 2.28
  - bgo#601567 - Import from git fails
  - bgo#585529 - Replace AnjutaMessageArea with GtkInfoBar
  - bgo#559925 - Send special keys to the terminal
  - bgo#602784 - Remove unneeded libsexy code
  - bgo#604581 - Crash Scintilla when writing a comment
  - bgo#599323 - symbol-db plugin can't create the symbol
    database
  - bgo#604954 - Configure project fail if project path contains
    space
  - bgo#604621 - specify /dev/shm at config time.
- Add anjuta-build-fix.patch to fix build.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 2.29.2.0:
  + String review
  + symbol-db: fix bgo#597113
  + search-plugin: unmerge ui and remove action group when the
    plugin is deactivated
  + git: remove action groups when the plugin is deactivated
  + file-manager: fix bug where we accessed the FileView even
    though it was freed
  + debug-manager: bgo#596009 - Easier adding of watches
  + bgo#601567 - Import from git fails
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1.0:
  + Fix check if the executable is part of the debug configuration
  + bgo#597318 -  Anjuta terminal crashes X
  + symbol-db: fix #597113
  + subversion: Fix duplicate IDs in the glade file (bgo#596001)
  + file-loader: bgo#567363 -  drag and drop from gnome-search-tool
    yields garbage message
- Drop anjuta-symboldb-fix.patch: fixed upstream.
- Drop anjuta-launchername.patch: fixed upstream.
- Drop anjuta-gtklabel-crash.patch: fixed upstream.
* Sat Oct 17 2009 dimstar@opensuse.org
- Add anjuta-launchername.patch, fixes X resets, bgo#597318,
  bnc#547917.
- Add anjuta-gtklabel-crash.patch, fixes crash due to malformed
  UI definition file, bgo#597815.
* Fri Oct 16 2009 dimstar@opensuse.org
- Add anjuta-symboldb-fix.patch, fix crash, bnc#547672, taken from
  upstream git.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0.0:
  + bgo#594665 - Fix link of test program
  + bgo#593954 - Report error when location is > 0 for markers
  + bgo#594648 - Terminal does not work
  + bgo#355151 - drag/drop into editor window should open file
  + Updated translations.
- Drop anjuta-link.patch, upstream fixed.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92.0:
  + class-gen: bgo#593532 - Untranslated strings
  + language-support-cpp-java: bgo#593291 - fix small typo
- Add anjuta-link.patch to fix build.
- Add gconf2-devel and gtk2-devel Requires to devel package.
* Thu Aug 27 2009 vuntz@novell.com
- Update to version 2.27.91.0:
  + Some git fixes (file-status, etc.)
  + Stability fixes on symbol-db
  + bgo#593236: Typo in Anjuta pot file
  + bgo#592941 – Fixed errors in Anjuta IDE Manual (Greek
    translation)
  + bgo#591758 - Fix language mistakes
  + bgo#591887 - Bad strings for translation
  + bgo#590117 – Build failure: local scandir() function collides
    with system's
  + bgo#589828 – Can't open GtkBuilder files with the glade plugin
  + bgo#590708 – Some untranslated strings
  + bgo#591359 – Need an easier and intuitive way to create a
    shared library project
  + bgo#590337 – Compile failure: not allowed to link against a
    module
  + bgo#590720 – glade plugin FTBFS on mips(el) and alpha,
    LANGUAGE_C built-in
  + bgo#575926 – 'Maintain past indentation' disables itself
  + bgo#578690 – Several components underlinked
  + bgo#585428 – Context needed to translate
  + bgo#590334 – Fix -I ordering
  + bgo#590338 – Missing plugins flags
  + bgo#566698 - git: Add init support
  + bgo#588112 - language-support-cpp-java: fixed infinite loop /
    freeze
  + bgo#587248 – Encoding key in desktop file is deprecated
  + bgo#588485 – fixes from running anjuta with
    G_DEBUG="fatal_warnings"
  + bgo#589699 – When ~/.cache isn't exists, session data isn't
    saved
  + bgo#588506 – Wrong value of PACKAGE_DOC_DIR
  + bgo#589601 – "gtk-execute" and "gtk-cancel" marked for
    translation
- Use spec-cleaner script to reorder lines in preamble.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5.0:
  + Even better git plugin
  + Work to get C++ autocompletion done
  + Bugs fixed:
  - bgo#589401 - git: Show the active branch in the status bar
  - bgo#588387 - symbol-db: make typeahead searching caseless
  - bgo#530740 - Migrate anjuta project wizards from libglade to
    GtkBuilder
  - bgo#575147 - Headers of new C++/GObject classes have wrong
    copyright and license notices.
  - bgo#577741 - "single step over function" does not always work
    as expected
  - bgo#587957 - doap file missing bug-database
  - bgo#583731 - Some untranslated strings
  - bgo#580276 - git: Refresh the log view when switching
    branches
  - bgo#578438 - broken svn libraries detection in configure
  - bgo#587191 - git: Fix a typo in a menu tooltip
  - bgo#586926 - gbf-am: build fix
  - bgo#586926 - gdbmi_test build fails
  - bgo#513156 - Get rid of libgnome(ui)
  - bgo#577924 - git: Add descriptions to the menu items
  - bgo#586621 - Crash while loading project file
  - bgo#586148 - Case had to be the other way around
  - bgo#586148 - Fixing setting whitespace for the editor not
    working
  - bgo#577924 - Fixing AnjutaStatusbar for displaying menu tags
  - bgo#577232 - run-program plugin: projects's working directory
    should be set to project root on start
  - bgo#586030 - Value of a new environment variable is not saved
    in run parameter dialog
  - bgo#584180 - Duplicate copy of GBF/General.pm installed to
    same location
  - bgo#582961 - Replace SexyIconEntry by GtkEntry icon
    functionality (available in GTK+ 2.16)
  - bgo#578411 - subversion: Show conflicted files in the commit
    dialog
  - bgo#585498 - symbol-db: Completion stop working and strange
    warning
- Remove libgnomeui-devel BuildRequires.
- Remove libgnomeui-devel Requires from devel package.
* Sun Jun 14 2009 vuntz@novell.com
- Update to version 2.27.3.0:
  + Updates:
  - Pixel-saving UI for tabs
  - Remove markup from translatable strings
  + Bugs fixed:
  - Lots of git bugs fixed
  - bgo#584013 - libanjuta-1.0.pc.in still requires libglade-2.0
  - bgo#584347 - Don't reference child revisions
  - bgo#567214 - bookmarks window wastes too much space
  - bgo#582464 - crash in Anjuta IDE: Hacking on Empathy, dele...
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2.0:
  + Lots of git improvements
  + Subversion improvements
  + Removed libglade dependency
  + bgo#581416 - Fix void function cannot return value
  + bgo#581869 - anjuta fails to build outside source tree
  + bgo#582710 - Please consider using g_timeout_add_seconds to
    reduce wakeups
  + bgo#582977 - String misspelled
  + bgo#581421 - build fail on symbol-db/test
  + bgo#530740 - Use GtkBuilder instead of libglade
  + bgo#583589 - Some untranslated strings
  + bgo#580340 - Reuse the last commit message when amending
    commits
- Remove libglade2-devel from devel Requires.
- Add anjuta-rpmlintrc for the warnings about the project
  templates.
* Wed May  6 2009 vuntz@novell.com
- Update to version 2.27.1.0:
  + Updates:
  - Improvements in git plugin
  - Improvements with auto-completion speed
  + Bugs fixed:
  - bgo#530740 - Use GtkBuilder instead of libglade
  - bgo#581074 - Creating a new wxWidgets project should not
    include libglade
  - bgo#580994 - using DEBUG_PRINT instead of g_print
  - bgo#580013 - patch plugin doesn't handle patch-files with
    whitespace
  - bgo#568779 - project wizard should infer project name from
    base path
  - bgo#577721 - tooltips appears in wrong position
  - bgo#579118 - Segmentation fault when adding file to project
  - bgo#578087 - Artwork for Symbol Database is actually not from
    Monodevelop
  - bgo#567588 - highlight default button in Find dialog
  - bgo#576959 - Search does not point to correct line number on
    first match when file is not opened in editor.
  - bgo#577006 - crash creating new file
  - bgo#574607 - Replace function selects text uncorrectly
  - bgo#576057 - doesn't build with graphviz 2.22.2
  - bgo#575617 - Update FSF address
- Remove libglade2-devel BuildRequires.
* Sun May  3 2009 mboman@suse.de
- Change BuildRequires from unique-devel to libunique-devel
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1.0:
  + New animation to identify running builds
  + bgo#578087 – Artwork for Symbol Database is actually not from
    Monodevelop team
  + bgo#564002 – Files view shows useless tooltip
* Wed Apr  8 2009 vuntz@novell.com
- Update to version 2.26.0.1:
  + Huge improvements in the tooltip area
  + Do not hang when pressing backspace in editor
  + bgo#574607 – Replace function selects text uncorrectly
  + bgo#576959 - Search does not point to correct line number on
    first match when file is not opened in editor.
  + bgo#574711 – Menu Toolbar unchecked at the first time while
    toolbar shown
  + bgo#574802 – show calltips makes the editing lag
  + bgo#576057 – doesn't build with graphviz 2.22.2
  + bgo#575893 – plugins schema files are not installed
  + bgo#575617 – Update FSF address
  + Updated translations.
- Changes from version 2.26.0:
  + bgo#397883 – The license info is almost empty
  + bgo#574376 – Save doesn't always save
  + bgo#573858 – link fail on Solaris for plugin symbol-db
  + bgo#562113 – Clean docbook syntax in order to validate
  + bgo#571740 – Get rid of deprecated libgnomecanvas
  + Fixed crash in git plugin
  + Fixed little problem in build plugin
  + Fixed distcheck
  + Updated translations.
- Use parallel make.
- Remove unneeded BuildRequires: gnome-common, gtk-doc, pcre-devel,
  sqlite-devel.
- Remove Requires that are automatically added: devhelp
- Remove some Requires which really seem abusive: alsa-devel,
  audiofile, esound-devel, gconf2-devel, gnome-terminal,
  gnome-vfs2-devel, libart_lgpl-devel, libbonobo-devel,
  libbonoboui-devel, libglade2-devel, libgnome-devel,
  libgnomecanvas-devel, libgnomeui-devel, libwnck-devel,
  libxml2-devel, openssl-devel, orbit2-devel, popt-devel, yelp,
  gnome-doc-utils
- Remove the Recommends for documentation: if we want them, they
  should really live in devhelp. And I'm not sure we want them.
- Pass --disable-static to configure and remove .la files.
- Package the anjuta-build-tutorial manual with the other manuals.
- Do not package omf files twice.
- Do not add DocPath to the desktop file: it's already there.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.903.0:
  + Valgrind memory fixes
  + Documentation fixes and updates
  + Fixes in the glade plugin
  + Version control integration fixes
  + Auto-indentation fixes
  + bgo#564282 – configure error: source directory already
    configured
  + bgo#567513 – Running configure doesn't make anjuta be aware
    that the project doesn't need a configure stage in its menus
  + bgo#565170 – Invalid read in plugin.c
  + bgo#573326 – Debug misfunction
  + bgo#572637 – Valgrind shows some errors in symbol-db
  + bgo#567068 – autocomplete box should vanish on backspace
  + bgo#564306 – don't ask which program to run if project has only
    one target
  + bgo#559806 – Anjuta crashes when closing unsaved file
  + bgo#556970 – Swap .h/.c doesn't work for C header files (*.h)
  + bgo#555895 – Save configure options for build configuration
  + bgo#572608 – crash clicking on 'find in files...' results.
  + bgo#572451 - crash on closing project
  + bgo#571760 – Find & Replace is broken (due to my previous
    changes)
  + bgo#511589 - remove missed includes
  + bgo#572289 – Make code less ambiguous
  + bgo#564891 – Crash when closing editor window
- Do not call autoreconf.
- Drop anjuta-fix-undefined-operation.patch: fixed upstream.
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 2.25.902:
  + Updates:
  - Code completion
  - Searching
  - Project Management
  + Bugs fixed:
  - bgo#570820 - problem with gtk+ trunk
  - bgo#564942 - display project-relative path in search results
    pane
  - bgo#571381 - Seach button disabled if no files opened.
  - bgo#571733 - file manager should sort files
    case-insensitively
  - bgo#571233 - Uncorrect loading of subversion plugin
  - bgo#571215 - doesn't indent function declarations correctly
  - bgo#570492 - Some criticals in the terminal plugin
  - bgo#556148 - it's impossible to remove project variables
  - bgo#571262 - gbf-am: treat tail slash as a package
  - bgo#566991 - list project modules in sorted order
  - bgo#571114 - Crash after clicking on Edit/Preferences with
    open document
  - bgo#571143 - Double free crasher of path string.
  - bgo#563704 - Anjuta displays column/line numbers after edit
    windows closed
  - bgo#556970 - Swap .h/.c doesn't work for C header files (*.h)
  - bgo#570720 - There are warnings in some cases when I press
    cancel in program arguments dialog
  - bgo#566785 - Anjuta crashes after enabling and disabling a
    plugin often
  - bgo#567606 - Auto-indentation in Anjuta gets tab indentation
    wrong for function paramaters
  - bgo#565015 - duplicate matches in search results pane
  - bgo#539580 - Uncorrect pass search result to
  - bgo#570614 - outdated download addresses
  - bgo#566531 - Find & Replace results in wrong result for files
    containing multi-byte UTF-8 sequences
  - bgo#570877 - symbol-db doesn't scan user-added packages.
  - bgo#570929 - initialize widgets before add watches.
  - bgo#566987 - display tooltip with prototype when calling
    function in project.
  - bgo#570245 - gbf gio-critical g_file_query_exists
  - bgo#566693 - Code completion of symbols usually not working
  - bgo#570492 - Canot open editor - crash
  - bgo#567100 - opening Find dialog causes GtkSpinButton warning
  - bgo#570444 - can't change numbers in preferences dialog
  - bgo#566987 - display tooltip with prototype when calling
    function in project
- Add anjuta-fix-undefined-operation.patch to fix a build error.
- Remove BuildRequires: gnome-build-devel, gnutls-devel,
  libgnomeprintui-devel, perl-XML-Parser, scrollkeeper
- Add BuildRequires: unique-devel.
- Remove Requires: libgnomeprint-devel, libgnomeprintui-devel
- Remove Recommends: libgnomeprint-doc, libgnomeprintui-doc
- Drop README.SuSE: I can't find any other mention of
  anjuta_update_global_tags, so I assume this is obsolete.
- Cleanup file list.
- Cleanup obsolete comments.
* Fri Feb  6 2009 hfiguiere@suse.de
- Revert some .spec change causing a breakage.
* Wed Feb  4 2009 hfiguiere@suse.de
- Update to 2.25.901
  + A large number of changes and fixes.
  + File-browser shows version control status for subversion using
    emblems
  + Remote debugging support using gdbserver
  + New bookmark interface
  + gnome-build merge into anjuta
  + Starter plugin for fast access to common actions
  + Symbol-db plugin now default and working, old ctags code and
    symbol-browser removed
  + Glade integration work (GSoc) merged
  + Support for scratchbox2
- Added perl-gettext and libgda-4_0-devel in the build requires.
* Fri Dec 26 2008 mboman@suse.de
- Use gtksourceview-devel instead of gtksourceview18-devel.
  Fixes bnc#461287
* Tue Nov 25 2008 ro@suse.de
- do not buildrequire valgrind on ia64 s390 s390x
  (does not exist on these platforms)
* Mon Oct 20 2008 mboman@suse.de
- Update to version 2.24.1:
  + bgo#545668 - new file are not added correctly to the project
  + bgo#545668 - file's icon not correctly updated on tabs-right-click
  + bgo#556053 - closing file tabs disable 'save button'
  + bgo#554684 - Cursor column number is not updated when typing text
  + Debugger was unable to start if build and source directory are different
  + Subversion: Make sure the repository URL given to the switch command is
    canonicalized.
  + bgo#554337 could not find glade file while executing a program
  + Translation updates
* Mon Sep 29 2008 mboman@suse.de
- Update to version 2.24.0.1:
  + New version of symbol-db plugin beta
  + Fix warnings, some documents could have no associated file
  + Fix bgo#529468: Use weak pointers to avoid acting on widgets that have
    been destroyed.
  + Fix bgo#551574 Project names and descriptions are not translatable
  + Fix bgo#551684: Wrong AC substitutions in anjuta-version.h.
  + Fixed a problem with async file loading.
  + Fix libanjuta API documentation
  + Imported new symbol icons from MonoDevelop.
  + Fix bgo#550322 - Newlines should be placed at the end of error messages
    lines
  + Fix bgo#550470 - Crash: Executing file through popup menu
  + Use the View->Editor->* menu items for view spaces, view eol and
    line wrap (new) option instead of the preferences.
  + Fix bgo#549950 - crash while saving a file
  + Translation updates
* Thu Sep  4 2008 maw@suse.de
- Update to version 2.23.91:
  + The large version bump is due to Anjuta synchronizing its
    version numbers with those of GNOME at large
  + Many bugfixes, updated translations, etc; for a fuller account
    see the included NEWS file.
* Tue Jul 15 2008 coolo@suse.de
- removing linking against shared bfd library, this makes updating
  bintuils impossible. If there is a bug in the static library,
  it should be fixed there
* Wed Apr  2 2008 vuntz@suse.de
- Remove -fno-strict-aliasing
- Add gdl-devel to Requires for the devel package
- Move *-doc from Requires to Recommends
- Clean up Requires by removing libraries when the devel package of
  the libraries are already in Requires
- Run ldconfig in %%post(un)
* Mon Mar 31 2008 vuntz@suse.de
- Updated to version 2.4.0. Too many changes and bugfixes to list
  here.
- Remove anjuta-64bit-warning.patch (fixed upstream),
  anjuta-svn-no-svn-config.patch (fixed upstream),
  anjuta-uninitalized-vars.patch (fixed upstream), abuild.patch
  (fixed upstream)
* Wed Feb  6 2008 rodrigo@suse.de
- Added patches to fix build failures
* Mon Feb  4 2008 ro@suse.de
- disable parallel make for the moment
* Mon Feb  4 2008 rodrigo@suse.de
- Fixed path for Glade catalog files
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 2.3.3:
  * http://ftp.acc.umu.se/pub/GNOME/sources/anjuta/2.3/anjuta-2.3.3.news
* Thu Jan 31 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
* Thu Nov  1 2007 sbrabec@suse.cz
- Build with gtksourceview18.
* Fri Oct 26 2007 sbrabec@suse.cz
- Require autogen (#336176).
- Fixed shared libbfd detection.
* Wed Oct 24 2007 sbrabec@suse.cz
- Build all optional plugins except GtkSourceView: subversion,
  glade, class inheritance, performance profiler, Valgrind.
* Tue Oct 23 2007 maw@suse.de
- Update to version 2.2.2:
  + Bugs (bugzilla.gnome.org) fixed: #477976, #427104, #479020,
    [#478238], #456465, #466031, #343522, #487112, #486597, #482067,
    [#477976], #427104, #487854, #474811, #488061, and #488928.
* Wed Oct 17 2007 maw@suse.de
- Add gdl-devel and libxslt-devel to the list of build requirements
- Remove configure.patch
- Don't attempt to install files that don't exist
- Split out a -devel subpackage
- Add abuild.patch
- Add no-bins-in-usrshare.patch
- Minor .spec cleanups.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Oct  8 2007 mauro@suse.de
- Update to version 2.2.1:
  * Fixed lots of memory leaks (thanks valgrind)
  * Fixed crasher on shutdown
  * Avoid an endless loop if clearing all breakpoints while the programm
  is running
  * Fixed help activation (bug #451557).
  * Fixed compiler warnings.
  * Fixed #423467 (View->Tasks menu items are not checked on startup)
  * Fixed anjuta-plugin template plugin by moving the "\" out of the [IF] block
  * Fixes bug #433552: crash in Anjuta IDE: add file test.h in project on
  generic Makefile.
  * Disables 'Add to project' in wizards for projects that can not add sources.
  * Fixed bug #450217: Refreshing tree brings to random crashes
  * Fixed bug 453931 - crash in Anjuta IDE: Trying some c++ exampled
  * Fixed bug 457093 - crash in Anjuta IDE: just typed in some text
* Fri Aug 10 2007 coolo@suse.de
- put the Version before the use of %%version
* Mon Aug  6 2007 maw@suse.de
- Split out a -lang subpackage
- Use %%fupes.
* Mon Jun 18 2007 maw@suse.de
- Add abuild.patch (#241836).
* Mon Apr 23 2007 pgajdos@suse.cz
- fixed new gcc warnings
- literal-comparsion.patch
* Wed Apr 18 2007 pgajdos@suse.cz
- fixed 'array subscript is above array bounds' [#248868]
- array-index.patch
* Thu Jan  4 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Fri Feb 24 2006 sbrabec@suse.cz
- Improved Categories.
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 1.2.4a.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed Oct 26 2005 sbrabec@suse.cz
- Updated to version 1.2.4 (#118228).
* Tue Aug  2 2005 ro@suse.de
- intltoolize with force
* Mon Jun 20 2005 sbrabec@suse.cz
- Removed mkinstalldirs patch - fixed upstream (#56985).
* Mon May 16 2005 sbrabec@suse.cz
- Updated to version 1.2.3.
* Wed Apr 27 2005 meissner@suse.de
- fixed buffer overflow and one aliasing issue.
* Tue Apr  5 2005 sbrabec@suse.cz
- Do not require linc.
* Sun Nov  7 2004 ro@suse.de
- make it build with new intltool
* Tue Oct 26 2004 ro@suse.de
- locale rename: no -> nb
* Tue Sep  7 2004 sbrabec@suse.cz
- Generated shared mime info.
* Mon Jul 12 2004 sbrabec@suse.cz
- Fixed default applications for GNOME2 (bug #42852).
  http://sourceforge.net/tracker/index.php?func=detail&aid=987912&group_id=14222&atid=314222
- Added gnome-terminal, yelp and devhelp to Requires.
- Added *-doc GNOME developer documentation to Requires.
* Tue Jun 15 2004 sbrabec@suse.cz
- Worked around missing mkinstalldirs (#42037, #41985).
* Thu Jun 10 2004 sbrabec@suse.cz
- Updated to version 1.2.2.
- Fixed IA64 crash on start (#41854).
* Sun Apr 25 2004 ro@suse.de
- fix function return type to void
* Wed Mar 17 2004 sbrabec@suse.cz
- Fixed scrollkeeper calling conventions (#36215).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Mon Mar 15 2004 sbrabec@suse.cz
- Added package set sufficient for compilation to requirements (#35900),
* Thu Feb 19 2004 ro@suse.de
- fix plugindir for lib64
* Thu Feb 12 2004 sbrabec@suse.cz
- Updated to version 1.2.1 (GNOME2).
- Added anjuta_update_global_tags.
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Thu Jul 24 2003 hhetter@suse.de
- %%_lib fixes
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 19 2003 ro@suse.de
- added directory to filelist
* Mon Jun  2 2003 ro@suse.de
- add manpages to filelist
- remove unpackaged files from buildroot
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
- changed neededforbuild <sp> to <opensp>
* Wed Nov  6 2002 hhetter@suse.de
- update to version 1.0.0
- package split en/ja documentation and translation
- completed scrollkeeper installation
- use correct kde datadir
- fix docbook usage
- full filelist rework
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Thu Aug 15 2002 ro@suse.de
- removed gnome-utils from neededforbuild
* Tue Aug 13 2002 hhetter@suse.de
- fix neededforbuild
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Mon Jul  1 2002 meissner@suse.de
- auto* rerun, added intltool to neededforbuild
* Mon Jul  1 2002 hhetter@suse.de
- updated to version 0.1.9
* Mon May 27 2002 ro@suse.de
- removed gpc from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Dec  5 2001 hhetter@suse.de
- update to version 0.1.8
  * first version after merging with gIDE
* Fri Aug 24 2001 hhetter@suse.de
- update to version 0.1.7, changes include:
  * translation and documentation updates
  * fixed bugs preventing use of the wizard
  * cleaned up user-interface
- filelist corrections and updates
- functionality test on i386
* Mon Aug 13 2001 hhetter@suse.de
- removed no longer needed patch
- updated to version 0.1.6
* Wed Jun 20 2001 hhetter@suse.de
- fixed redundand docdir
* Thu Apr  5 2001 uli@suse.de
- ditched reimplementation of strcasestr (harmful with recent gccs)
- fixed passing of RPM_OPT_FLAGS
* Thu Mar 29 2001 hhetter@suse.de
- update to version 0.1.4
- use bz2
- filelist review
* Wed Mar 14 2001 hhetter@suse.de
- changed docdir from gnome/anjuta/ to anjuta/
- filelist corrections
* Mon Mar 12 2001 hhetter@suse.de
- Update to version 0.1.3
- filelist corrections/updates
- testrun on 7.1
* Mon Jan 22 2001 hhetter@suse.de
- inital build
